@@ -19,10 +19,10 @@ import uuid
 from abc import abstractmethod
 from typing import Any, List, Optional
 
-from core.crud.crud_entity import CrudEntity
-from core.crud.crud_repository import CrudRepository
-from core.crud.file.file_storage import FileStorage
-from core.exception.exceptions import ProgrammingError
+from hspylib.core.crud.crud_entity import CrudEntity
+from hspylib.core.crud.crud_repository import CrudRepository
+from hspylib.core.crud.file.file_storage import FileStorage
+from hspylib.core.exception.exceptions import ProgrammingError
 
 
 class FileRepository(CrudRepository):
