@@ -81,7 +81,7 @@ def strip_escapes(string: str) -> str:
 
 def remove_linebreaks(text: str) -> str:
     """TODO"""
-    return re.sub(re.compile(r'\s+'), '', text)
+    return re.sub(re.compile(r'(\n|\r|\n\r)+'), '', text)
 
 
 def print_unicode(uni_code: Union[str, int]) -> None:
